==> ejc-doc-impl-3.0.0-20210202.090237-34-sources.jar: com/ejianc/business/doc/bean/KbmCollectEntity.java <==
package com.ejianc.business.doc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.List;

/**
 * 知识库收藏夹
 *
 * @author generator
 *
 */
 @TableName("ejc_doc_kbm_collect")
public class KbmCollectEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="title")
    private String title; // 标题
    @TableField(value="collect_describe")
    private String collectDescribe; // 描述说明
    @TableField(value="last_time")
    private java.util.Date lastTime; // 最后收藏时间
    @TableField(value="create_user_id")
    private Long createUserId; // 创建人ID

    /**
     * 收藏夹详情集合
     */
    @TableField(exist = false)
    @SubEntity(serviceName="kbmCollectDetailService",pidName = "kbmId")
    private List<KbmCollectDetailEntity>  collectDetailList;

    /**
     * 标题
     */
    public String getTitle() {
        return title;
    }

    /**
     * 标题
     */
    public void setTitle(String title) {
        this.title = title;
    }
    /**
     * 描述说明
     */
    public String getCollectDescribe() {
        return collectDescribe;
    }

    /**
     * 描述说明
     */
    public void setCollectDescribe(String collectDescribe) {
        this.collectDescribe = collectDescribe;
    }
    /**
     * 最后收藏时间
     */
    public java.util.Date getLastTime() {
        return lastTime;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    /**
     * 最后收藏时间
     */
    public void setLastTime(java.util.Date lastTime) {
        this.lastTime = lastTime;
    }

    public List<KbmCollectDetailEntity> getCollectDetailList() {
        return collectDetailList;
    }

    public void setCollectDetailList(List<KbmCollectDetailEntity> collectDetailList) {
        this.collectDetailList = collectDetailList;
    }
}

==> ejc-doc-impl-3.0.0-20210203.013905-38-sources.jar: com/ejianc/business/doc/bean/KbmCollectEntity.java <==
package com.ejianc.business.doc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.List;

/**
 * 知识库收藏夹
 *
 * @author generator
 *
 */
 @TableName("ejc_doc_kbm_collect")
public class KbmCollectEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="title")
    private String title; // 标题
    @TableField(value="collect_describe")
    private String collectDescribe; // 描述说明
    @TableField(value="last_time")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date lastTime; // 最后收藏时间
    @TableField(value="create_user_id")
    private Long createUserId; // 创建人ID

    /**
     * 收藏夹详情集合
     */
    @TableField(exist = false)
    @SubEntity(serviceName="kbmCollectDetailService",pidName = "kbmId")
    private List<KbmCollectDetailEntity>  collectDetailList;

    /**
     * 标题
     */
    public String getTitle() {
        return title;
    }

    /**
     * 标题
     */
    public void setTitle(String title) {
        this.title = title;
    }
    /**
     * 描述说明
     */
    public String getCollectDescribe() {
        return collectDescribe;
    }

    /**
     * 描述说明
     */
    public void setCollectDescribe(String collectDescribe) {
        this.collectDescribe = collectDescribe;
    }
    /**
     * 最后收藏时间
     */
    public java.util.Date getLastTime() {
        return lastTime;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    /**
     * 最后收藏时间
     */
    public void setLastTime(java.util.Date lastTime) {
        this.lastTime = lastTime;
    }

    public List<KbmCollectDetailEntity> getCollectDetailList() {
        return collectDetailList;
    }

    public void setCollectDetailList(List<KbmCollectDetailEntity> collectDetailList) {
        this.collectDetailList = collectDetailList;
    }
}
